pub struct TabDialog { /* private fields */ }Expand description
A dialog-like view with tabs. This is very similar to the TabPanel view in cursive_tabs
Implementations
Sourceimpl TabDialog
impl TabDialog
Add a new button to the dialog
Add a new button to the dialog
Chainable variant
Add a button to close the dialog
Add a button to close the dialog
Chainable variant
Add buttons to cycle through the tabs
Add buttons to cycle through the tabs
Chainable variant
Add a button to remove the current tab
Add a button to remove the current tab
Chainable variant
Set the alignment of the buttons
Set the alignment of the buttons
Chainable variant
Sourcepub fn set_title_align(&mut self, align: HAlign)
pub fn set_title_align(&mut self, align: HAlign)
Set the alignment of the buttons
Sourcepub fn title_align(self, align: HAlign) -> Self
pub fn title_align(self, align: HAlign) -> Self
Set the alignment of the buttons
Chainable variant
Remove all the buttons
Sourcepub fn cur_view_mut(&mut self) -> Option<&mut BoxedView>
pub fn cur_view_mut(&mut self) -> Option<&mut BoxedView>
Mutable version of cur_view()
Sourcepub fn cur_title(&self) -> Option<&str>
pub fn cur_title(&self) -> Option<&str>
The current tab title
Returns an empty string if the tab dialog is empty
Sourcepub fn views_mut(&mut self) -> TabIterMut<'_>
pub fn views_mut(&mut self) -> TabIterMut<'_>
Mutable version of views()
Sourcepub fn set_cur_tab(&mut self, id: usize)
pub fn set_cur_tab(&mut self, id: usize)
Set the current tab by ID
Sourcepub fn add_tab<V: View>(&mut self, title: &str, view: V) -> usize
pub fn add_tab<V: View>(&mut self, title: &str, view: V) -> usize
Add a new view tab and returns the ID of the new tab
Sourcepub fn tab<V: View>(self, title: &str, view: V) -> TabDialog
pub fn tab<V: View>(self, title: &str, view: V) -> TabDialog
Add a new view tab
Chainable version
Sourcepub fn remove_tab(&mut self, id: usize)
pub fn remove_tab(&mut self, id: usize)
Delete tab by ID